ConflictingKeyRange

Struct ConflictingKeyRange 

pub struct ConflictingKeyRange { /* private fields */ }
A key range that conflicted during a transaction commit.

Returned by Transaction::conflicting_keys after a commit conflict when TransactionOption::ReportConflictingKeys is enabled.

The special keyspace encodes conflicting ranges using boundary markers:

  • Value b"1" marks the inclusive start of a conflicting range
  • Value b"0" marks the exclusive end of a conflicting range

Implementations

Source

impl ConflictingKeyRange

pub fn begin(&self) -> &[u8]

The inclusive begin of the conflicting key range.

pub fn end(&self) -> &[u8]

The exclusive end of the conflicting key range.