foundationdb

Struct MaybeCommitted

pub struct MaybeCommitted(/* private fields */);
Whether any earlier attempt in this run may have committed.

Once true, this remains true for every subsequent attempt, even if later attempts fail with errors that are known not to have committed. Convert it to a boolean with bool::from when checking the flag.