pub struct ConflictingKeyRange { /* private fields */ }Expand description
A key range that conflicted during a transaction commit.
Returned by Transaction::conflicting_keys after a commit conflict
when TransactionOption::ReportConflictingKeys
is enabled.
The special keyspace encodes conflicting ranges using boundary markers:
- Value
b"1"marks the inclusive start of a conflicting range - Value
b"0"marks the exclusive end of a conflicting range
Implementations